Contributing
============

Issues
------

Bug reports, feature requests, and other contributions are welcome. If you find
a demonstrable problem that is caused by the REANA code, please:

1. Search for `already reported problems
   <https://github.com/reanahub/reana-db/issues>`_.
2. Check if the issue has been fixed or is still reproducible on the
   latest `master` branch.
3. Create an issue, ideally with **a test case**.

Pull requests
-------------

If you create a feature branch, you can run the tests to ensure that everything
is operating correctly:

.. code-block:: console

    $ ./run-tests.sh

Each pull request should preserve or increase code coverage.

Kanban
------

We are using Kanban technique for keeping track of ongoing tasks. Please see our
`Kanban board <https://waffle.io/reanahub/reana>`_ and look for issues that are
labelled as "ready for work".
